// Copyright (c) Microsoft Corporation
// All rights reserved. 
//
// Licensed under the Apache License, Version 2.0 (the ""License""); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED ON AN  *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT. 
//
// See the Apache Version 2.0 License for specific language governing permissions and limitations under the License.

#define NTDDI_VERSION 0x06010000

#include <v8.h>
#include <string>
#include <node_object_wrap.h>
#include <ppltasks.h>
#include "CollectionsConverter.h"
#include "CollectionsWrap.h"
#include "node-async.h"
#include "NodeRtUtils.h"
#include "OpaqueWrapper.h"
#include "WrapperBase.h"

#using <Windows.WinMD>

// this undefs fixes the issues of compiling Windows.Data.Json, Windows.Storag.FileProperties, and Windows.Stroage.Search
// Some of the node header files brings windows definitions with the same names as some of the WinRT methods
#undef DocumentProperties
#undef GetObject
#undef CreateEvent
#undef FindText
#undef SendMessage

const char* REGISTRATION_TOKEN_MAP_PROPERTY_NAME = "__registrationTokenMap__";

using namespace v8;
using namespace node;
using namespace concurrency;

namespace NodeRT { namespace Windows { namespace Devices { namespace Sensors { 
  v8::Handle<v8::Value> WrapAccelerometer(::Windows::Devices::Sensors::Accelerometer^ wintRtInstance);
  ::Windows::Devices::Sensors::Accelerometer^ UnwrapAccelerometer(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapAccelerometerReading(::Windows::Devices::Sensors::AccelerometerReading^ wintRtInstance);
  ::Windows::Devices::Sensors::AccelerometerReading^ UnwrapAccelerometerReading(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapAccelerometerReadingChangedEventArgs(::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^ wintRtInstance);
  ::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^ UnwrapAccelerometerReadingChangedEventArgs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapAccelerometerShakenEventArgs(::Windows::Devices::Sensors::AccelerometerShakenEventArgs^ wintRtInstance);
  ::Windows::Devices::Sensors::AccelerometerShakenEventArgs^ UnwrapAccelerometerShakenEventArgs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapInclinometer(::Windows::Devices::Sensors::Inclinometer^ wintRtInstance);
  ::Windows::Devices::Sensors::Inclinometer^ UnwrapInclinometer(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapInclinometerReading(::Windows::Devices::Sensors::InclinometerReading^ wintRtInstance);
  ::Windows::Devices::Sensors::InclinometerReading^ UnwrapInclinometerReading(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapInclinometerReadingChangedEventArgs(::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^ wintRtInstance);
  ::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^ UnwrapInclinometerReadingChangedEventArgs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapGyrometer(::Windows::Devices::Sensors::Gyrometer^ wintRtInstance);
  ::Windows::Devices::Sensors::Gyrometer^ UnwrapGyrometer(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapGyrometerReading(::Windows::Devices::Sensors::GyrometerReading^ wintRtInstance);
  ::Windows::Devices::Sensors::GyrometerReading^ UnwrapGyrometerReading(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapGyrometerReadingChangedEventArgs(::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^ wintRtInstance);
  ::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^ UnwrapGyrometerReadingChangedEventArgs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapCompass(::Windows::Devices::Sensors::Compass^ wintRtInstance);
  ::Windows::Devices::Sensors::Compass^ UnwrapCompass(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapCompassReading(::Windows::Devices::Sensors::CompassReading^ wintRtInstance);
  ::Windows::Devices::Sensors::CompassReading^ UnwrapCompassReading(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapCompassReadingChangedEventArgs(::Windows::Devices::Sensors::CompassReadingChangedEventArgs^ wintRtInstance);
  ::Windows::Devices::Sensors::CompassReadingChangedEventArgs^ UnwrapCompassReadingChangedEventArgs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapLightSensor(::Windows::Devices::Sensors::LightSensor^ wintRtInstance);
  ::Windows::Devices::Sensors::LightSensor^ UnwrapLightSensor(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapLightSensorReading(::Windows::Devices::Sensors::LightSensorReading^ wintRtInstance);
  ::Windows::Devices::Sensors::LightSensorReading^ UnwrapLightSensorReading(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapLightSensorReadingChangedEventArgs(::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^ wintRtInstance);
  ::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^ UnwrapLightSensorReadingChangedEventArgs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSensorRotationMatrix(::Windows::Devices::Sensors::SensorRotationMatrix^ wintRtInstance);
  ::Windows::Devices::Sensors::SensorRotationMatrix^ UnwrapSensorRotationMatrix(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSensorQuaternion(::Windows::Devices::Sensors::SensorQuaternion^ wintRtInstance);
  ::Windows::Devices::Sensors::SensorQuaternion^ UnwrapSensorQuaternion(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapOrientationSensor(::Windows::Devices::Sensors::OrientationSensor^ wintRtInstance);
  ::Windows::Devices::Sensors::OrientationSensor^ UnwrapOrientationSensor(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapOrientationSensorReading(::Windows::Devices::Sensors::OrientationSensorReading^ wintRtInstance);
  ::Windows::Devices::Sensors::OrientationSensorReading^ UnwrapOrientationSensorReading(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapOrientationSensorReadingChangedEventArgs(::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^ wintRtInstance);
  ::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^ UnwrapOrientationSensorReadingChangedEventArgs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSimpleOrientationSensor(::Windows::Devices::Sensors::SimpleOrientationSensor^ wintRtInstance);
  ::Windows::Devices::Sensors::SimpleOrientationSensor^ UnwrapSimpleOrientationSensor(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSimpleOrientationSensorOrientationChangedEventArgs(::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^ wintRtInstance);
  ::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^ UnwrapSimpleOrientationSensorOrientationChangedEventArgs(Handle<Value> value);
  


  static v8::Handle<v8::Value> InitMagnetometerAccuracyEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("MagnetometerAccuracy"), enumObject);

    enumObject->Set(String::NewSymbol("unknown"), Integer::New(0));
    enumObject->Set(String::NewSymbol("unreliable"), Integer::New(1));
    enumObject->Set(String::NewSymbol("approximate"), Integer::New(2));
    enumObject->Set(String::NewSymbol("high"), Integer::New(3));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitSimpleOrientationEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("SimpleOrientation"), enumObject);

    enumObject->Set(String::NewSymbol("notRotated"), Integer::New(0));
    enumObject->Set(String::NewSymbol("rotated90DegreesCounterclockwise"), Integer::New(1));
    enumObject->Set(String::NewSymbol("rotated180DegreesCounterclockwise"), Integer::New(2));
    enumObject->Set(String::NewSymbol("rotated270DegreesCounterclockwise"), Integer::New(3));
    enumObject->Set(String::NewSymbol("faceup"), Integer::New(4));
    enumObject->Set(String::NewSymbol("facedown"), Integer::New(5));

    return scope.Close(Undefined());
  }



  
  class Accelerometer : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("Accelerometer"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getCurrentReading"), FunctionTemplate::New(GetCurrentReading)->GetFunction());
      
                  
      Local<Function> addListenerFunc = FunctionTemplate::New(AddListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("addListener"), addListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("on"), addListenerFunc);
      Local<Function> removeListenerFunc = FunctionTemplate::New(RemoveListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeListener"), removeListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("off"), removeListenerFunc);
            
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reportInterval"), ReportIntervalGetter, ReportIntervalSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("minimumReportInterval"), MinimumReportIntervalGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("getDefault"), FunctionTemplate::New(GetDefault)->GetFunction());

      exports->Set(String::NewSymbol("Accelerometer"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    Accelerometer(::Windows::Devices::Sensors::Accelerometer^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::Accelerometer^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Accelerometer^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::Accelerometer^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      Accelerometer *wrapperInstance = new Accelerometer(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetCurrentReading(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Accelerometer^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      Accelerometer *wrapper = Accelerometer::Unwrap<Accelerometer>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::AccelerometerReading^ result;
          result = wrapper->_instance->GetCurrentReading();
          return scope.Close(WrapAccelerometerReading(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> GetDefault(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::Accelerometer^ result;
          result = ::Windows::Devices::Sensors::Accelerometer::GetDefault();
          return scope.Close(WrapAccelerometer(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> ReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Accelerometer^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Accelerometer *wrapper = Accelerometer::Unwrap<Accelerometer>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->ReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ReportIntervalSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsUint32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Accelerometer^>(info.This()))
      {
        return;
      }

      Accelerometer *wrapper = Accelerometer::Unwrap<Accelerometer>(info.This());

      try 
      {
        
        unsigned int winRtValue = static_cast<unsigned int>(value->IntegerValue());

        wrapper->_instance->ReportInterval = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MinimumReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Accelerometer^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Accelerometer *wrapper = Accelerometer::Unwrap<Accelerometer>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->MinimumReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


    static v8::Handle<v8::Value> AddListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected arguments are eventName(string),callback(function)")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;
      
      Local<Function> callback = args[1].As<Function>();
      
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Accelerometer^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        Accelerometer *wrapper = Accelerometer::Unwrap<Accelerometer>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->ReadingChanged::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Devices::Sensors::Accelerometer^, ::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^>(
            [callbackObjPtr](::Windows::Devices::Sensors::Accelerometer^ arg0, ::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapAccelerometer(arg0);
                Handle<Value> wrappedArg1 = WrapAccelerometerReadingChangedEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else if (NodeRT::Utils::CaseInsenstiveEquals(L"shaken", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Accelerometer^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        Accelerometer *wrapper = Accelerometer::Unwrap<Accelerometer>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->Shaken::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Devices::Sensors::Accelerometer^, ::Windows::Devices::Sensors::AccelerometerShakenEventArgs^>(
            [callbackObjPtr](::Windows::Devices::Sensors::Accelerometer^ arg0, ::Windows::Devices::Sensors::AccelerometerShakenEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapAccelerometer(arg0);
                Handle<Value> wrappedArg1 = WrapAccelerometerShakenEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else 
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
          tokenMap = Object::New();
          callback->SetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME), tokenMap);
      }

      tokenMap.As<Object>()->Set(args[1], CreateOpaqueWrapper(::Windows::Foundation::PropertyValue::CreateInt64(registrationToken.Value)));
                
      return scope.Close(Undefined());
    }

    static v8::Handle<v8::Value> RemoveListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected a string and a callback")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;

      if ((NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str)) &&(NodeRT::Utils::CaseInsenstiveEquals(L"shaken", str)))
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Function> callback = args[1].As<Function>();
      Handle<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      Handle<Value> opaqueWrapperObj =  tokenMap.As<Object>()->Get(args[1]);

      if (opaqueWrapperObj.IsEmpty() || opaqueWrapperObj->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      OpaqueWrapper *opaqueWrapper = OpaqueWrapper::Unwrap<OpaqueWrapper>(opaqueWrapperObj.As<Object>());
            
      long long tokenValue = (long long) opaqueWrapper->GetObjectInstance();
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      registrationToken.Value = tokenValue;
        
      try 
      {
        if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Accelerometer^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          Accelerometer *wrapper = Accelerometer::Unwrap<Accelerometer>(args.This());
          wrapper->_instance->ReadingChanged::remove(registrationToken);
        }
        else if (NodeRT::Utils::CaseInsenstiveEquals(L"shaken", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Accelerometer^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          Accelerometer *wrapper = Accelerometer::Unwrap<Accelerometer>(args.This());
          wrapper->_instance->Shaken::remove(registrationToken);
        }
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }

      tokenMap.As<Object>()->Delete(args[0].As<String>());

      return scope.Close(Undefined());
    }
  private:
    ::Windows::Devices::Sensors::Accelerometer^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapAccelerometer(::Windows::Devices::Sensors::Accelerometer^ wintRtInstance);
    friend ::Windows::Devices::Sensors::Accelerometer^ UnwrapAccelerometer(Handle<Value> value);
    friend bool IsAccelerometerWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> Accelerometer::s_constructorTemplate;

  v8::Handle<v8::Value> WrapAccelerometer(::Windows::Devices::Sensors::Accelerometer^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(Accelerometer::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::Accelerometer^ UnwrapAccelerometer(Handle<Value> value)
  {
     return Accelerometer::Unwrap<Accelerometer>(value.As<Object>())->_instance;
  }

  void InitAccelerometer(Handle<Object> exports)
  {
    Accelerometer::Init(exports);
  }

  class AccelerometerReading : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("AccelerometerReading"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("accelerationX"), AccelerationXGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("accelerationY"), AccelerationYGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("accelerationZ"), AccelerationZGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("timestamp"), TimestampGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("AccelerometerReading"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    AccelerometerReading(::Windows::Devices::Sensors::AccelerometerReading^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::AccelerometerReading^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::AccelerometerReading^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::AccelerometerReading^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      AccelerometerReading *wrapperInstance = new AccelerometerReading(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> AccelerationXGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::AccelerometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      AccelerometerReading *wrapper = AccelerometerReading::Unwrap<AccelerometerReading>(info.This());

      try 
      {
        double result = wrapper->_instance->AccelerationX;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AccelerationYGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::AccelerometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      AccelerometerReading *wrapper = AccelerometerReading::Unwrap<AccelerometerReading>(info.This());

      try 
      {
        double result = wrapper->_instance->AccelerationY;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AccelerationZGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::AccelerometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      AccelerometerReading *wrapper = AccelerometerReading::Unwrap<AccelerometerReading>(info.This());

      try 
      {
        double result = wrapper->_instance->AccelerationZ;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TimestampGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::AccelerometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      AccelerometerReading *wrapper = AccelerometerReading::Unwrap<AccelerometerReading>(info.This());

      try 
      {
        ::Windows::Foundation::DateTime result = wrapper->_instance->Timestamp;
        return scope.Close(NodeRT::Utils::DateTimeToJS(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::AccelerometerReading^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapAccelerometerReading(::Windows::Devices::Sensors::AccelerometerReading^ wintRtInstance);
    friend ::Windows::Devices::Sensors::AccelerometerReading^ UnwrapAccelerometerReading(Handle<Value> value);
    friend bool IsAccelerometerReadingWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> AccelerometerReading::s_constructorTemplate;

  v8::Handle<v8::Value> WrapAccelerometerReading(::Windows::Devices::Sensors::AccelerometerReading^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(AccelerometerReading::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::AccelerometerReading^ UnwrapAccelerometerReading(Handle<Value> value)
  {
     return AccelerometerReading::Unwrap<AccelerometerReading>(value.As<Object>())->_instance;
  }

  void InitAccelerometerReading(Handle<Object> exports)
  {
    AccelerometerReading::Init(exports);
  }

  class AccelerometerReadingChangedEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("AccelerometerReadingChangedEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reading"), ReadingGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("AccelerometerReadingChangedEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    AccelerometerReadingChangedEventArgs(::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      AccelerometerReadingChangedEventArgs *wrapperInstance = new AccelerometerReadingChangedEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> ReadingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      AccelerometerReadingChangedEventArgs *wrapper = AccelerometerReadingChangedEventArgs::Unwrap<AccelerometerReadingChangedEventArgs>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::AccelerometerReading^ result = wrapper->_instance->Reading;
        return scope.Close(WrapAccelerometerReading(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapAccelerometerReadingChangedEventArgs(::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^ wintRtInstance);
    friend ::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^ UnwrapAccelerometerReadingChangedEventArgs(Handle<Value> value);
    friend bool IsAccelerometerReadingChangedEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> AccelerometerReadingChangedEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapAccelerometerReadingChangedEventArgs(::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(AccelerometerReadingChangedEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::AccelerometerReadingChangedEventArgs^ UnwrapAccelerometerReadingChangedEventArgs(Handle<Value> value)
  {
     return AccelerometerReadingChangedEventArgs::Unwrap<AccelerometerReadingChangedEventArgs>(value.As<Object>())->_instance;
  }

  void InitAccelerometerReadingChangedEventArgs(Handle<Object> exports)
  {
    AccelerometerReadingChangedEventArgs::Init(exports);
  }

  class AccelerometerShakenEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("AccelerometerShakenEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("timestamp"), TimestampGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("AccelerometerShakenEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    AccelerometerShakenEventArgs(::Windows::Devices::Sensors::AccelerometerShakenEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::AccelerometerShakenEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::AccelerometerShakenEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::AccelerometerShakenEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      AccelerometerShakenEventArgs *wrapperInstance = new AccelerometerShakenEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> TimestampGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::AccelerometerShakenEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      AccelerometerShakenEventArgs *wrapper = AccelerometerShakenEventArgs::Unwrap<AccelerometerShakenEventArgs>(info.This());

      try 
      {
        ::Windows::Foundation::DateTime result = wrapper->_instance->Timestamp;
        return scope.Close(NodeRT::Utils::DateTimeToJS(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::AccelerometerShakenEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapAccelerometerShakenEventArgs(::Windows::Devices::Sensors::AccelerometerShakenEventArgs^ wintRtInstance);
    friend ::Windows::Devices::Sensors::AccelerometerShakenEventArgs^ UnwrapAccelerometerShakenEventArgs(Handle<Value> value);
    friend bool IsAccelerometerShakenEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> AccelerometerShakenEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapAccelerometerShakenEventArgs(::Windows::Devices::Sensors::AccelerometerShakenEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(AccelerometerShakenEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::AccelerometerShakenEventArgs^ UnwrapAccelerometerShakenEventArgs(Handle<Value> value)
  {
     return AccelerometerShakenEventArgs::Unwrap<AccelerometerShakenEventArgs>(value.As<Object>())->_instance;
  }

  void InitAccelerometerShakenEventArgs(Handle<Object> exports)
  {
    AccelerometerShakenEventArgs::Init(exports);
  }

  class Inclinometer : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("Inclinometer"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getCurrentReading"), FunctionTemplate::New(GetCurrentReading)->GetFunction());
      
                  
      Local<Function> addListenerFunc = FunctionTemplate::New(AddListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("addListener"), addListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("on"), addListenerFunc);
      Local<Function> removeListenerFunc = FunctionTemplate::New(RemoveListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeListener"), removeListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("off"), removeListenerFunc);
            
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reportInterval"), ReportIntervalGetter, ReportIntervalSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("minimumReportInterval"), MinimumReportIntervalGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("getDefault"), FunctionTemplate::New(GetDefault)->GetFunction());

      exports->Set(String::NewSymbol("Inclinometer"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    Inclinometer(::Windows::Devices::Sensors::Inclinometer^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::Inclinometer^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Inclinometer^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::Inclinometer^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      Inclinometer *wrapperInstance = new Inclinometer(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetCurrentReading(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Inclinometer^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      Inclinometer *wrapper = Inclinometer::Unwrap<Inclinometer>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::InclinometerReading^ result;
          result = wrapper->_instance->GetCurrentReading();
          return scope.Close(WrapInclinometerReading(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> GetDefault(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::Inclinometer^ result;
          result = ::Windows::Devices::Sensors::Inclinometer::GetDefault();
          return scope.Close(WrapInclinometer(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> ReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Inclinometer^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Inclinometer *wrapper = Inclinometer::Unwrap<Inclinometer>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->ReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ReportIntervalSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsUint32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Inclinometer^>(info.This()))
      {
        return;
      }

      Inclinometer *wrapper = Inclinometer::Unwrap<Inclinometer>(info.This());

      try 
      {
        
        unsigned int winRtValue = static_cast<unsigned int>(value->IntegerValue());

        wrapper->_instance->ReportInterval = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MinimumReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Inclinometer^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Inclinometer *wrapper = Inclinometer::Unwrap<Inclinometer>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->MinimumReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


    static v8::Handle<v8::Value> AddListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected arguments are eventName(string),callback(function)")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;
      
      Local<Function> callback = args[1].As<Function>();
      
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Inclinometer^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        Inclinometer *wrapper = Inclinometer::Unwrap<Inclinometer>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->ReadingChanged::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Devices::Sensors::Inclinometer^, ::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^>(
            [callbackObjPtr](::Windows::Devices::Sensors::Inclinometer^ arg0, ::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapInclinometer(arg0);
                Handle<Value> wrappedArg1 = WrapInclinometerReadingChangedEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else 
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
          tokenMap = Object::New();
          callback->SetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME), tokenMap);
      }

      tokenMap.As<Object>()->Set(args[1], CreateOpaqueWrapper(::Windows::Foundation::PropertyValue::CreateInt64(registrationToken.Value)));
                
      return scope.Close(Undefined());
    }

    static v8::Handle<v8::Value> RemoveListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected a string and a callback")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;

      if ((NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str)))
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Function> callback = args[1].As<Function>();
      Handle<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      Handle<Value> opaqueWrapperObj =  tokenMap.As<Object>()->Get(args[1]);

      if (opaqueWrapperObj.IsEmpty() || opaqueWrapperObj->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      OpaqueWrapper *opaqueWrapper = OpaqueWrapper::Unwrap<OpaqueWrapper>(opaqueWrapperObj.As<Object>());
            
      long long tokenValue = (long long) opaqueWrapper->GetObjectInstance();
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      registrationToken.Value = tokenValue;
        
      try 
      {
        if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Inclinometer^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          Inclinometer *wrapper = Inclinometer::Unwrap<Inclinometer>(args.This());
          wrapper->_instance->ReadingChanged::remove(registrationToken);
        }
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }

      tokenMap.As<Object>()->Delete(args[0].As<String>());

      return scope.Close(Undefined());
    }
  private:
    ::Windows::Devices::Sensors::Inclinometer^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapInclinometer(::Windows::Devices::Sensors::Inclinometer^ wintRtInstance);
    friend ::Windows::Devices::Sensors::Inclinometer^ UnwrapInclinometer(Handle<Value> value);
    friend bool IsInclinometerWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> Inclinometer::s_constructorTemplate;

  v8::Handle<v8::Value> WrapInclinometer(::Windows::Devices::Sensors::Inclinometer^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(Inclinometer::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::Inclinometer^ UnwrapInclinometer(Handle<Value> value)
  {
     return Inclinometer::Unwrap<Inclinometer>(value.As<Object>())->_instance;
  }

  void InitInclinometer(Handle<Object> exports)
  {
    Inclinometer::Init(exports);
  }

  class InclinometerReading : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("InclinometerReading"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("pitchDegrees"), PitchDegreesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("rollDegrees"), RollDegreesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("timestamp"), TimestampGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("yawDegrees"), YawDegreesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("yawAccuracy"), YawAccuracyGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("InclinometerReading"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    InclinometerReading(::Windows::Devices::Sensors::InclinometerReading^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::InclinometerReading^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::InclinometerReading^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::InclinometerReading^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      InclinometerReading *wrapperInstance = new InclinometerReading(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> PitchDegreesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::InclinometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      InclinometerReading *wrapper = InclinometerReading::Unwrap<InclinometerReading>(info.This());

      try 
      {
        float result = wrapper->_instance->PitchDegrees;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RollDegreesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::InclinometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      InclinometerReading *wrapper = InclinometerReading::Unwrap<InclinometerReading>(info.This());

      try 
      {
        float result = wrapper->_instance->RollDegrees;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TimestampGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::InclinometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      InclinometerReading *wrapper = InclinometerReading::Unwrap<InclinometerReading>(info.This());

      try 
      {
        ::Windows::Foundation::DateTime result = wrapper->_instance->Timestamp;
        return scope.Close(NodeRT::Utils::DateTimeToJS(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> YawDegreesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::InclinometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      InclinometerReading *wrapper = InclinometerReading::Unwrap<InclinometerReading>(info.This());

      try 
      {
        float result = wrapper->_instance->YawDegrees;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> YawAccuracyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::InclinometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      InclinometerReading *wrapper = InclinometerReading::Unwrap<InclinometerReading>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::MagnetometerAccuracy result = wrapper->_instance->YawAccuracy;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::InclinometerReading^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapInclinometerReading(::Windows::Devices::Sensors::InclinometerReading^ wintRtInstance);
    friend ::Windows::Devices::Sensors::InclinometerReading^ UnwrapInclinometerReading(Handle<Value> value);
    friend bool IsInclinometerReadingWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> InclinometerReading::s_constructorTemplate;

  v8::Handle<v8::Value> WrapInclinometerReading(::Windows::Devices::Sensors::InclinometerReading^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(InclinometerReading::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::InclinometerReading^ UnwrapInclinometerReading(Handle<Value> value)
  {
     return InclinometerReading::Unwrap<InclinometerReading>(value.As<Object>())->_instance;
  }

  void InitInclinometerReading(Handle<Object> exports)
  {
    InclinometerReading::Init(exports);
  }

  class InclinometerReadingChangedEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("InclinometerReadingChangedEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reading"), ReadingGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("InclinometerReadingChangedEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    InclinometerReadingChangedEventArgs(::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      InclinometerReadingChangedEventArgs *wrapperInstance = new InclinometerReadingChangedEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> ReadingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      InclinometerReadingChangedEventArgs *wrapper = InclinometerReadingChangedEventArgs::Unwrap<InclinometerReadingChangedEventArgs>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::InclinometerReading^ result = wrapper->_instance->Reading;
        return scope.Close(WrapInclinometerReading(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapInclinometerReadingChangedEventArgs(::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^ wintRtInstance);
    friend ::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^ UnwrapInclinometerReadingChangedEventArgs(Handle<Value> value);
    friend bool IsInclinometerReadingChangedEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> InclinometerReadingChangedEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapInclinometerReadingChangedEventArgs(::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(InclinometerReadingChangedEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::InclinometerReadingChangedEventArgs^ UnwrapInclinometerReadingChangedEventArgs(Handle<Value> value)
  {
     return InclinometerReadingChangedEventArgs::Unwrap<InclinometerReadingChangedEventArgs>(value.As<Object>())->_instance;
  }

  void InitInclinometerReadingChangedEventArgs(Handle<Object> exports)
  {
    InclinometerReadingChangedEventArgs::Init(exports);
  }

  class Gyrometer : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("Gyrometer"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getCurrentReading"), FunctionTemplate::New(GetCurrentReading)->GetFunction());
      
                  
      Local<Function> addListenerFunc = FunctionTemplate::New(AddListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("addListener"), addListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("on"), addListenerFunc);
      Local<Function> removeListenerFunc = FunctionTemplate::New(RemoveListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeListener"), removeListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("off"), removeListenerFunc);
            
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reportInterval"), ReportIntervalGetter, ReportIntervalSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("minimumReportInterval"), MinimumReportIntervalGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("getDefault"), FunctionTemplate::New(GetDefault)->GetFunction());

      exports->Set(String::NewSymbol("Gyrometer"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    Gyrometer(::Windows::Devices::Sensors::Gyrometer^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::Gyrometer^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Gyrometer^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::Gyrometer^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      Gyrometer *wrapperInstance = new Gyrometer(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetCurrentReading(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Gyrometer^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      Gyrometer *wrapper = Gyrometer::Unwrap<Gyrometer>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::GyrometerReading^ result;
          result = wrapper->_instance->GetCurrentReading();
          return scope.Close(WrapGyrometerReading(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> GetDefault(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::Gyrometer^ result;
          result = ::Windows::Devices::Sensors::Gyrometer::GetDefault();
          return scope.Close(WrapGyrometer(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> ReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Gyrometer^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Gyrometer *wrapper = Gyrometer::Unwrap<Gyrometer>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->ReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ReportIntervalSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsUint32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Gyrometer^>(info.This()))
      {
        return;
      }

      Gyrometer *wrapper = Gyrometer::Unwrap<Gyrometer>(info.This());

      try 
      {
        
        unsigned int winRtValue = static_cast<unsigned int>(value->IntegerValue());

        wrapper->_instance->ReportInterval = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MinimumReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Gyrometer^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Gyrometer *wrapper = Gyrometer::Unwrap<Gyrometer>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->MinimumReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


    static v8::Handle<v8::Value> AddListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected arguments are eventName(string),callback(function)")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;
      
      Local<Function> callback = args[1].As<Function>();
      
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Gyrometer^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        Gyrometer *wrapper = Gyrometer::Unwrap<Gyrometer>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->ReadingChanged::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Devices::Sensors::Gyrometer^, ::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^>(
            [callbackObjPtr](::Windows::Devices::Sensors::Gyrometer^ arg0, ::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapGyrometer(arg0);
                Handle<Value> wrappedArg1 = WrapGyrometerReadingChangedEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else 
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
          tokenMap = Object::New();
          callback->SetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME), tokenMap);
      }

      tokenMap.As<Object>()->Set(args[1], CreateOpaqueWrapper(::Windows::Foundation::PropertyValue::CreateInt64(registrationToken.Value)));
                
      return scope.Close(Undefined());
    }

    static v8::Handle<v8::Value> RemoveListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected a string and a callback")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;

      if ((NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str)))
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Function> callback = args[1].As<Function>();
      Handle<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      Handle<Value> opaqueWrapperObj =  tokenMap.As<Object>()->Get(args[1]);

      if (opaqueWrapperObj.IsEmpty() || opaqueWrapperObj->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      OpaqueWrapper *opaqueWrapper = OpaqueWrapper::Unwrap<OpaqueWrapper>(opaqueWrapperObj.As<Object>());
            
      long long tokenValue = (long long) opaqueWrapper->GetObjectInstance();
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      registrationToken.Value = tokenValue;
        
      try 
      {
        if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Gyrometer^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          Gyrometer *wrapper = Gyrometer::Unwrap<Gyrometer>(args.This());
          wrapper->_instance->ReadingChanged::remove(registrationToken);
        }
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }

      tokenMap.As<Object>()->Delete(args[0].As<String>());

      return scope.Close(Undefined());
    }
  private:
    ::Windows::Devices::Sensors::Gyrometer^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapGyrometer(::Windows::Devices::Sensors::Gyrometer^ wintRtInstance);
    friend ::Windows::Devices::Sensors::Gyrometer^ UnwrapGyrometer(Handle<Value> value);
    friend bool IsGyrometerWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> Gyrometer::s_constructorTemplate;

  v8::Handle<v8::Value> WrapGyrometer(::Windows::Devices::Sensors::Gyrometer^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(Gyrometer::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::Gyrometer^ UnwrapGyrometer(Handle<Value> value)
  {
     return Gyrometer::Unwrap<Gyrometer>(value.As<Object>())->_instance;
  }

  void InitGyrometer(Handle<Object> exports)
  {
    Gyrometer::Init(exports);
  }

  class GyrometerReading : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("GyrometerReading"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("angularVelocityX"), AngularVelocityXGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("angularVelocityY"), AngularVelocityYGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("angularVelocityZ"), AngularVelocityZGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("timestamp"), TimestampGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("GyrometerReading"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    GyrometerReading(::Windows::Devices::Sensors::GyrometerReading^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::GyrometerReading^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::GyrometerReading^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::GyrometerReading^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      GyrometerReading *wrapperInstance = new GyrometerReading(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> AngularVelocityXGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::GyrometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GyrometerReading *wrapper = GyrometerReading::Unwrap<GyrometerReading>(info.This());

      try 
      {
        double result = wrapper->_instance->AngularVelocityX;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AngularVelocityYGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::GyrometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GyrometerReading *wrapper = GyrometerReading::Unwrap<GyrometerReading>(info.This());

      try 
      {
        double result = wrapper->_instance->AngularVelocityY;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AngularVelocityZGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::GyrometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GyrometerReading *wrapper = GyrometerReading::Unwrap<GyrometerReading>(info.This());

      try 
      {
        double result = wrapper->_instance->AngularVelocityZ;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TimestampGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::GyrometerReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GyrometerReading *wrapper = GyrometerReading::Unwrap<GyrometerReading>(info.This());

      try 
      {
        ::Windows::Foundation::DateTime result = wrapper->_instance->Timestamp;
        return scope.Close(NodeRT::Utils::DateTimeToJS(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::GyrometerReading^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapGyrometerReading(::Windows::Devices::Sensors::GyrometerReading^ wintRtInstance);
    friend ::Windows::Devices::Sensors::GyrometerReading^ UnwrapGyrometerReading(Handle<Value> value);
    friend bool IsGyrometerReadingWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> GyrometerReading::s_constructorTemplate;

  v8::Handle<v8::Value> WrapGyrometerReading(::Windows::Devices::Sensors::GyrometerReading^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(GyrometerReading::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::GyrometerReading^ UnwrapGyrometerReading(Handle<Value> value)
  {
     return GyrometerReading::Unwrap<GyrometerReading>(value.As<Object>())->_instance;
  }

  void InitGyrometerReading(Handle<Object> exports)
  {
    GyrometerReading::Init(exports);
  }

  class GyrometerReadingChangedEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("GyrometerReadingChangedEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reading"), ReadingGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("GyrometerReadingChangedEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    GyrometerReadingChangedEventArgs(::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      GyrometerReadingChangedEventArgs *wrapperInstance = new GyrometerReadingChangedEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> ReadingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GyrometerReadingChangedEventArgs *wrapper = GyrometerReadingChangedEventArgs::Unwrap<GyrometerReadingChangedEventArgs>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::GyrometerReading^ result = wrapper->_instance->Reading;
        return scope.Close(WrapGyrometerReading(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapGyrometerReadingChangedEventArgs(::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^ wintRtInstance);
    friend ::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^ UnwrapGyrometerReadingChangedEventArgs(Handle<Value> value);
    friend bool IsGyrometerReadingChangedEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> GyrometerReadingChangedEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapGyrometerReadingChangedEventArgs(::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(GyrometerReadingChangedEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::GyrometerReadingChangedEventArgs^ UnwrapGyrometerReadingChangedEventArgs(Handle<Value> value)
  {
     return GyrometerReadingChangedEventArgs::Unwrap<GyrometerReadingChangedEventArgs>(value.As<Object>())->_instance;
  }

  void InitGyrometerReadingChangedEventArgs(Handle<Object> exports)
  {
    GyrometerReadingChangedEventArgs::Init(exports);
  }

  class Compass : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("Compass"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getCurrentReading"), FunctionTemplate::New(GetCurrentReading)->GetFunction());
      
                  
      Local<Function> addListenerFunc = FunctionTemplate::New(AddListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("addListener"), addListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("on"), addListenerFunc);
      Local<Function> removeListenerFunc = FunctionTemplate::New(RemoveListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeListener"), removeListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("off"), removeListenerFunc);
            
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reportInterval"), ReportIntervalGetter, ReportIntervalSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("minimumReportInterval"), MinimumReportIntervalGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("getDefault"), FunctionTemplate::New(GetDefault)->GetFunction());

      exports->Set(String::NewSymbol("Compass"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    Compass(::Windows::Devices::Sensors::Compass^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::Compass^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Compass^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::Compass^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      Compass *wrapperInstance = new Compass(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetCurrentReading(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Compass^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      Compass *wrapper = Compass::Unwrap<Compass>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::CompassReading^ result;
          result = wrapper->_instance->GetCurrentReading();
          return scope.Close(WrapCompassReading(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> GetDefault(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::Compass^ result;
          result = ::Windows::Devices::Sensors::Compass::GetDefault();
          return scope.Close(WrapCompass(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> ReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Compass^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Compass *wrapper = Compass::Unwrap<Compass>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->ReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ReportIntervalSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsUint32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Compass^>(info.This()))
      {
        return;
      }

      Compass *wrapper = Compass::Unwrap<Compass>(info.This());

      try 
      {
        
        unsigned int winRtValue = static_cast<unsigned int>(value->IntegerValue());

        wrapper->_instance->ReportInterval = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MinimumReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Compass^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      Compass *wrapper = Compass::Unwrap<Compass>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->MinimumReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


    static v8::Handle<v8::Value> AddListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected arguments are eventName(string),callback(function)")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;
      
      Local<Function> callback = args[1].As<Function>();
      
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Compass^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        Compass *wrapper = Compass::Unwrap<Compass>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->ReadingChanged::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Devices::Sensors::Compass^, ::Windows::Devices::Sensors::CompassReadingChangedEventArgs^>(
            [callbackObjPtr](::Windows::Devices::Sensors::Compass^ arg0, ::Windows::Devices::Sensors::CompassReadingChangedEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapCompass(arg0);
                Handle<Value> wrappedArg1 = WrapCompassReadingChangedEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else 
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
          tokenMap = Object::New();
          callback->SetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME), tokenMap);
      }

      tokenMap.As<Object>()->Set(args[1], CreateOpaqueWrapper(::Windows::Foundation::PropertyValue::CreateInt64(registrationToken.Value)));
                
      return scope.Close(Undefined());
    }

    static v8::Handle<v8::Value> RemoveListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected a string and a callback")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;

      if ((NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str)))
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Function> callback = args[1].As<Function>();
      Handle<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      Handle<Value> opaqueWrapperObj =  tokenMap.As<Object>()->Get(args[1]);

      if (opaqueWrapperObj.IsEmpty() || opaqueWrapperObj->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      OpaqueWrapper *opaqueWrapper = OpaqueWrapper::Unwrap<OpaqueWrapper>(opaqueWrapperObj.As<Object>());
            
      long long tokenValue = (long long) opaqueWrapper->GetObjectInstance();
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      registrationToken.Value = tokenValue;
        
      try 
      {
        if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::Compass^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          Compass *wrapper = Compass::Unwrap<Compass>(args.This());
          wrapper->_instance->ReadingChanged::remove(registrationToken);
        }
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }

      tokenMap.As<Object>()->Delete(args[0].As<String>());

      return scope.Close(Undefined());
    }
  private:
    ::Windows::Devices::Sensors::Compass^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapCompass(::Windows::Devices::Sensors::Compass^ wintRtInstance);
    friend ::Windows::Devices::Sensors::Compass^ UnwrapCompass(Handle<Value> value);
    friend bool IsCompassWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> Compass::s_constructorTemplate;

  v8::Handle<v8::Value> WrapCompass(::Windows::Devices::Sensors::Compass^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(Compass::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::Compass^ UnwrapCompass(Handle<Value> value)
  {
     return Compass::Unwrap<Compass>(value.As<Object>())->_instance;
  }

  void InitCompass(Handle<Object> exports)
  {
    Compass::Init(exports);
  }

  class CompassReading : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("CompassReading"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("headingMagneticNorth"), HeadingMagneticNorthGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("headingTrueNorth"), HeadingTrueNorthGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("timestamp"), TimestampGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("headingAccuracy"), HeadingAccuracyGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("CompassReading"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    CompassReading(::Windows::Devices::Sensors::CompassReading^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::CompassReading^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::CompassReading^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::CompassReading^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      CompassReading *wrapperInstance = new CompassReading(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> HeadingMagneticNorthGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::CompassReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      CompassReading *wrapper = CompassReading::Unwrap<CompassReading>(info.This());

      try 
      {
        double result = wrapper->_instance->HeadingMagneticNorth;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> HeadingTrueNorthGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::CompassReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      CompassReading *wrapper = CompassReading::Unwrap<CompassReading>(info.This());

      try 
      {
        ::Platform::IBox<double>^ result = wrapper->_instance->HeadingTrueNorth;
        return scope.Close(result ? Number::New(static_cast<double>(result->Value)): static_cast<Handle<Value>>(Undefined()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TimestampGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::CompassReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      CompassReading *wrapper = CompassReading::Unwrap<CompassReading>(info.This());

      try 
      {
        ::Windows::Foundation::DateTime result = wrapper->_instance->Timestamp;
        return scope.Close(NodeRT::Utils::DateTimeToJS(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> HeadingAccuracyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::CompassReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      CompassReading *wrapper = CompassReading::Unwrap<CompassReading>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::MagnetometerAccuracy result = wrapper->_instance->HeadingAccuracy;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::CompassReading^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapCompassReading(::Windows::Devices::Sensors::CompassReading^ wintRtInstance);
    friend ::Windows::Devices::Sensors::CompassReading^ UnwrapCompassReading(Handle<Value> value);
    friend bool IsCompassReadingWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> CompassReading::s_constructorTemplate;

  v8::Handle<v8::Value> WrapCompassReading(::Windows::Devices::Sensors::CompassReading^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(CompassReading::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::CompassReading^ UnwrapCompassReading(Handle<Value> value)
  {
     return CompassReading::Unwrap<CompassReading>(value.As<Object>())->_instance;
  }

  void InitCompassReading(Handle<Object> exports)
  {
    CompassReading::Init(exports);
  }

  class CompassReadingChangedEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("CompassReadingChangedEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reading"), ReadingGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("CompassReadingChangedEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    CompassReadingChangedEventArgs(::Windows::Devices::Sensors::CompassReadingChangedEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::CompassReadingChangedEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::CompassReadingChangedEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::CompassReadingChangedEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      CompassReadingChangedEventArgs *wrapperInstance = new CompassReadingChangedEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> ReadingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::CompassReadingChangedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      CompassReadingChangedEventArgs *wrapper = CompassReadingChangedEventArgs::Unwrap<CompassReadingChangedEventArgs>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::CompassReading^ result = wrapper->_instance->Reading;
        return scope.Close(WrapCompassReading(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::CompassReadingChangedEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapCompassReadingChangedEventArgs(::Windows::Devices::Sensors::CompassReadingChangedEventArgs^ wintRtInstance);
    friend ::Windows::Devices::Sensors::CompassReadingChangedEventArgs^ UnwrapCompassReadingChangedEventArgs(Handle<Value> value);
    friend bool IsCompassReadingChangedEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> CompassReadingChangedEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapCompassReadingChangedEventArgs(::Windows::Devices::Sensors::CompassReadingChangedEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(CompassReadingChangedEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::CompassReadingChangedEventArgs^ UnwrapCompassReadingChangedEventArgs(Handle<Value> value)
  {
     return CompassReadingChangedEventArgs::Unwrap<CompassReadingChangedEventArgs>(value.As<Object>())->_instance;
  }

  void InitCompassReadingChangedEventArgs(Handle<Object> exports)
  {
    CompassReadingChangedEventArgs::Init(exports);
  }

  class LightSensor : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("LightSensor"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getCurrentReading"), FunctionTemplate::New(GetCurrentReading)->GetFunction());
      
                  
      Local<Function> addListenerFunc = FunctionTemplate::New(AddListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("addListener"), addListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("on"), addListenerFunc);
      Local<Function> removeListenerFunc = FunctionTemplate::New(RemoveListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeListener"), removeListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("off"), removeListenerFunc);
            
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reportInterval"), ReportIntervalGetter, ReportIntervalSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("minimumReportInterval"), MinimumReportIntervalGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("getDefault"), FunctionTemplate::New(GetDefault)->GetFunction());

      exports->Set(String::NewSymbol("LightSensor"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    LightSensor(::Windows::Devices::Sensors::LightSensor^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::LightSensor^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensor^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::LightSensor^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      LightSensor *wrapperInstance = new LightSensor(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetCurrentReading(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensor^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      LightSensor *wrapper = LightSensor::Unwrap<LightSensor>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::LightSensorReading^ result;
          result = wrapper->_instance->GetCurrentReading();
          return scope.Close(WrapLightSensorReading(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> GetDefault(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::LightSensor^ result;
          result = ::Windows::Devices::Sensors::LightSensor::GetDefault();
          return scope.Close(WrapLightSensor(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> ReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensor^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      LightSensor *wrapper = LightSensor::Unwrap<LightSensor>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->ReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ReportIntervalSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsUint32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensor^>(info.This()))
      {
        return;
      }

      LightSensor *wrapper = LightSensor::Unwrap<LightSensor>(info.This());

      try 
      {
        
        unsigned int winRtValue = static_cast<unsigned int>(value->IntegerValue());

        wrapper->_instance->ReportInterval = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MinimumReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensor^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      LightSensor *wrapper = LightSensor::Unwrap<LightSensor>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->MinimumReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


    static v8::Handle<v8::Value> AddListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected arguments are eventName(string),callback(function)")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;
      
      Local<Function> callback = args[1].As<Function>();
      
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensor^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        LightSensor *wrapper = LightSensor::Unwrap<LightSensor>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->ReadingChanged::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Devices::Sensors::LightSensor^, ::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^>(
            [callbackObjPtr](::Windows::Devices::Sensors::LightSensor^ arg0, ::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapLightSensor(arg0);
                Handle<Value> wrappedArg1 = WrapLightSensorReadingChangedEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else 
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
          tokenMap = Object::New();
          callback->SetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME), tokenMap);
      }

      tokenMap.As<Object>()->Set(args[1], CreateOpaqueWrapper(::Windows::Foundation::PropertyValue::CreateInt64(registrationToken.Value)));
                
      return scope.Close(Undefined());
    }

    static v8::Handle<v8::Value> RemoveListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected a string and a callback")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;

      if ((NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str)))
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Function> callback = args[1].As<Function>();
      Handle<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      Handle<Value> opaqueWrapperObj =  tokenMap.As<Object>()->Get(args[1]);

      if (opaqueWrapperObj.IsEmpty() || opaqueWrapperObj->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      OpaqueWrapper *opaqueWrapper = OpaqueWrapper::Unwrap<OpaqueWrapper>(opaqueWrapperObj.As<Object>());
            
      long long tokenValue = (long long) opaqueWrapper->GetObjectInstance();
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      registrationToken.Value = tokenValue;
        
      try 
      {
        if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensor^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          LightSensor *wrapper = LightSensor::Unwrap<LightSensor>(args.This());
          wrapper->_instance->ReadingChanged::remove(registrationToken);
        }
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }

      tokenMap.As<Object>()->Delete(args[0].As<String>());

      return scope.Close(Undefined());
    }
  private:
    ::Windows::Devices::Sensors::LightSensor^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapLightSensor(::Windows::Devices::Sensors::LightSensor^ wintRtInstance);
    friend ::Windows::Devices::Sensors::LightSensor^ UnwrapLightSensor(Handle<Value> value);
    friend bool IsLightSensorWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> LightSensor::s_constructorTemplate;

  v8::Handle<v8::Value> WrapLightSensor(::Windows::Devices::Sensors::LightSensor^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(LightSensor::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::LightSensor^ UnwrapLightSensor(Handle<Value> value)
  {
     return LightSensor::Unwrap<LightSensor>(value.As<Object>())->_instance;
  }

  void InitLightSensor(Handle<Object> exports)
  {
    LightSensor::Init(exports);
  }

  class LightSensorReading : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("LightSensorReading"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("illuminanceInLux"), IlluminanceInLuxGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("timestamp"), TimestampGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("LightSensorReading"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    LightSensorReading(::Windows::Devices::Sensors::LightSensorReading^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::LightSensorReading^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensorReading^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::LightSensorReading^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      LightSensorReading *wrapperInstance = new LightSensorReading(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> IlluminanceInLuxGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensorReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      LightSensorReading *wrapper = LightSensorReading::Unwrap<LightSensorReading>(info.This());

      try 
      {
        float result = wrapper->_instance->IlluminanceInLux;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TimestampGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensorReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      LightSensorReading *wrapper = LightSensorReading::Unwrap<LightSensorReading>(info.This());

      try 
      {
        ::Windows::Foundation::DateTime result = wrapper->_instance->Timestamp;
        return scope.Close(NodeRT::Utils::DateTimeToJS(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::LightSensorReading^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapLightSensorReading(::Windows::Devices::Sensors::LightSensorReading^ wintRtInstance);
    friend ::Windows::Devices::Sensors::LightSensorReading^ UnwrapLightSensorReading(Handle<Value> value);
    friend bool IsLightSensorReadingWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> LightSensorReading::s_constructorTemplate;

  v8::Handle<v8::Value> WrapLightSensorReading(::Windows::Devices::Sensors::LightSensorReading^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(LightSensorReading::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::LightSensorReading^ UnwrapLightSensorReading(Handle<Value> value)
  {
     return LightSensorReading::Unwrap<LightSensorReading>(value.As<Object>())->_instance;
  }

  void InitLightSensorReading(Handle<Object> exports)
  {
    LightSensorReading::Init(exports);
  }

  class LightSensorReadingChangedEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("LightSensorReadingChangedEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reading"), ReadingGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("LightSensorReadingChangedEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    LightSensorReadingChangedEventArgs(::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      LightSensorReadingChangedEventArgs *wrapperInstance = new LightSensorReadingChangedEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> ReadingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      LightSensorReadingChangedEventArgs *wrapper = LightSensorReadingChangedEventArgs::Unwrap<LightSensorReadingChangedEventArgs>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::LightSensorReading^ result = wrapper->_instance->Reading;
        return scope.Close(WrapLightSensorReading(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapLightSensorReadingChangedEventArgs(::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^ wintRtInstance);
    friend ::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^ UnwrapLightSensorReadingChangedEventArgs(Handle<Value> value);
    friend bool IsLightSensorReadingChangedEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> LightSensorReadingChangedEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapLightSensorReadingChangedEventArgs(::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(LightSensorReadingChangedEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::LightSensorReadingChangedEventArgs^ UnwrapLightSensorReadingChangedEventArgs(Handle<Value> value)
  {
     return LightSensorReadingChangedEventArgs::Unwrap<LightSensorReadingChangedEventArgs>(value.As<Object>())->_instance;
  }

  void InitLightSensorReadingChangedEventArgs(Handle<Object> exports)
  {
    LightSensorReadingChangedEventArgs::Init(exports);
  }

  class SensorRotationMatrix : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SensorRotationMatrix"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("m11"), M11Getter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("m12"), M12Getter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("m13"), M13Getter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("m21"), M21Getter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("m22"), M22Getter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("m23"), M23Getter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("m31"), M31Getter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("m32"), M32Getter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("m33"), M33Getter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("SensorRotationMatrix"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SensorRotationMatrix(::Windows::Devices::Sensors::SensorRotationMatrix^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::SensorRotationMatrix^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorRotationMatrix^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::SensorRotationMatrix^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SensorRotationMatrix *wrapperInstance = new SensorRotationMatrix(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> M11Getter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorRotationMatrix^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorRotationMatrix *wrapper = SensorRotationMatrix::Unwrap<SensorRotationMatrix>(info.This());

      try 
      {
        float result = wrapper->_instance->M11;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> M12Getter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorRotationMatrix^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorRotationMatrix *wrapper = SensorRotationMatrix::Unwrap<SensorRotationMatrix>(info.This());

      try 
      {
        float result = wrapper->_instance->M12;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> M13Getter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorRotationMatrix^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorRotationMatrix *wrapper = SensorRotationMatrix::Unwrap<SensorRotationMatrix>(info.This());

      try 
      {
        float result = wrapper->_instance->M13;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> M21Getter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorRotationMatrix^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorRotationMatrix *wrapper = SensorRotationMatrix::Unwrap<SensorRotationMatrix>(info.This());

      try 
      {
        float result = wrapper->_instance->M21;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> M22Getter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorRotationMatrix^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorRotationMatrix *wrapper = SensorRotationMatrix::Unwrap<SensorRotationMatrix>(info.This());

      try 
      {
        float result = wrapper->_instance->M22;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> M23Getter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorRotationMatrix^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorRotationMatrix *wrapper = SensorRotationMatrix::Unwrap<SensorRotationMatrix>(info.This());

      try 
      {
        float result = wrapper->_instance->M23;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> M31Getter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorRotationMatrix^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorRotationMatrix *wrapper = SensorRotationMatrix::Unwrap<SensorRotationMatrix>(info.This());

      try 
      {
        float result = wrapper->_instance->M31;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> M32Getter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorRotationMatrix^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorRotationMatrix *wrapper = SensorRotationMatrix::Unwrap<SensorRotationMatrix>(info.This());

      try 
      {
        float result = wrapper->_instance->M32;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> M33Getter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorRotationMatrix^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorRotationMatrix *wrapper = SensorRotationMatrix::Unwrap<SensorRotationMatrix>(info.This());

      try 
      {
        float result = wrapper->_instance->M33;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::SensorRotationMatrix^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSensorRotationMatrix(::Windows::Devices::Sensors::SensorRotationMatrix^ wintRtInstance);
    friend ::Windows::Devices::Sensors::SensorRotationMatrix^ UnwrapSensorRotationMatrix(Handle<Value> value);
    friend bool IsSensorRotationMatrixWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SensorRotationMatrix::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSensorRotationMatrix(::Windows::Devices::Sensors::SensorRotationMatrix^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SensorRotationMatrix::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::SensorRotationMatrix^ UnwrapSensorRotationMatrix(Handle<Value> value)
  {
     return SensorRotationMatrix::Unwrap<SensorRotationMatrix>(value.As<Object>())->_instance;
  }

  void InitSensorRotationMatrix(Handle<Object> exports)
  {
    SensorRotationMatrix::Init(exports);
  }

  class SensorQuaternion : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SensorQuaternion"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("w"), WGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("x"), XGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("y"), YGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("z"), ZGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("SensorQuaternion"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SensorQuaternion(::Windows::Devices::Sensors::SensorQuaternion^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::SensorQuaternion^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorQuaternion^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::SensorQuaternion^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SensorQuaternion *wrapperInstance = new SensorQuaternion(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> WGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorQuaternion^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorQuaternion *wrapper = SensorQuaternion::Unwrap<SensorQuaternion>(info.This());

      try 
      {
        float result = wrapper->_instance->W;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> XGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorQuaternion^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorQuaternion *wrapper = SensorQuaternion::Unwrap<SensorQuaternion>(info.This());

      try 
      {
        float result = wrapper->_instance->X;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> YGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorQuaternion^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorQuaternion *wrapper = SensorQuaternion::Unwrap<SensorQuaternion>(info.This());

      try 
      {
        float result = wrapper->_instance->Y;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ZGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SensorQuaternion^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SensorQuaternion *wrapper = SensorQuaternion::Unwrap<SensorQuaternion>(info.This());

      try 
      {
        float result = wrapper->_instance->Z;
        return scope.Close(Number::New(static_cast<double>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::SensorQuaternion^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSensorQuaternion(::Windows::Devices::Sensors::SensorQuaternion^ wintRtInstance);
    friend ::Windows::Devices::Sensors::SensorQuaternion^ UnwrapSensorQuaternion(Handle<Value> value);
    friend bool IsSensorQuaternionWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SensorQuaternion::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSensorQuaternion(::Windows::Devices::Sensors::SensorQuaternion^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SensorQuaternion::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::SensorQuaternion^ UnwrapSensorQuaternion(Handle<Value> value)
  {
     return SensorQuaternion::Unwrap<SensorQuaternion>(value.As<Object>())->_instance;
  }

  void InitSensorQuaternion(Handle<Object> exports)
  {
    SensorQuaternion::Init(exports);
  }

  class OrientationSensor : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("OrientationSensor"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getCurrentReading"), FunctionTemplate::New(GetCurrentReading)->GetFunction());
      
                  
      Local<Function> addListenerFunc = FunctionTemplate::New(AddListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("addListener"), addListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("on"), addListenerFunc);
      Local<Function> removeListenerFunc = FunctionTemplate::New(RemoveListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeListener"), removeListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("off"), removeListenerFunc);
            
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reportInterval"), ReportIntervalGetter, ReportIntervalSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("minimumReportInterval"), MinimumReportIntervalGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("getDefault"), FunctionTemplate::New(GetDefault)->GetFunction());

      exports->Set(String::NewSymbol("OrientationSensor"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    OrientationSensor(::Windows::Devices::Sensors::OrientationSensor^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::OrientationSensor^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensor^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::OrientationSensor^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      OrientationSensor *wrapperInstance = new OrientationSensor(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetCurrentReading(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensor^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      OrientationSensor *wrapper = OrientationSensor::Unwrap<OrientationSensor>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::OrientationSensorReading^ result;
          result = wrapper->_instance->GetCurrentReading();
          return scope.Close(WrapOrientationSensorReading(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> GetDefault(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::OrientationSensor^ result;
          result = ::Windows::Devices::Sensors::OrientationSensor::GetDefault();
          return scope.Close(WrapOrientationSensor(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> ReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensor^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      OrientationSensor *wrapper = OrientationSensor::Unwrap<OrientationSensor>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->ReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ReportIntervalSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsUint32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensor^>(info.This()))
      {
        return;
      }

      OrientationSensor *wrapper = OrientationSensor::Unwrap<OrientationSensor>(info.This());

      try 
      {
        
        unsigned int winRtValue = static_cast<unsigned int>(value->IntegerValue());

        wrapper->_instance->ReportInterval = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MinimumReportIntervalGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensor^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      OrientationSensor *wrapper = OrientationSensor::Unwrap<OrientationSensor>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->MinimumReportInterval;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


    static v8::Handle<v8::Value> AddListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected arguments are eventName(string),callback(function)")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;
      
      Local<Function> callback = args[1].As<Function>();
      
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensor^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        OrientationSensor *wrapper = OrientationSensor::Unwrap<OrientationSensor>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->ReadingChanged::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Devices::Sensors::OrientationSensor^, ::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^>(
            [callbackObjPtr](::Windows::Devices::Sensors::OrientationSensor^ arg0, ::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapOrientationSensor(arg0);
                Handle<Value> wrappedArg1 = WrapOrientationSensorReadingChangedEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else 
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
          tokenMap = Object::New();
          callback->SetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME), tokenMap);
      }

      tokenMap.As<Object>()->Set(args[1], CreateOpaqueWrapper(::Windows::Foundation::PropertyValue::CreateInt64(registrationToken.Value)));
                
      return scope.Close(Undefined());
    }

    static v8::Handle<v8::Value> RemoveListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected a string and a callback")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;

      if ((NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str)))
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Function> callback = args[1].As<Function>();
      Handle<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      Handle<Value> opaqueWrapperObj =  tokenMap.As<Object>()->Get(args[1]);

      if (opaqueWrapperObj.IsEmpty() || opaqueWrapperObj->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      OpaqueWrapper *opaqueWrapper = OpaqueWrapper::Unwrap<OpaqueWrapper>(opaqueWrapperObj.As<Object>());
            
      long long tokenValue = (long long) opaqueWrapper->GetObjectInstance();
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      registrationToken.Value = tokenValue;
        
      try 
      {
        if (NodeRT::Utils::CaseInsenstiveEquals(L"readingChanged", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensor^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          OrientationSensor *wrapper = OrientationSensor::Unwrap<OrientationSensor>(args.This());
          wrapper->_instance->ReadingChanged::remove(registrationToken);
        }
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }

      tokenMap.As<Object>()->Delete(args[0].As<String>());

      return scope.Close(Undefined());
    }
  private:
    ::Windows::Devices::Sensors::OrientationSensor^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapOrientationSensor(::Windows::Devices::Sensors::OrientationSensor^ wintRtInstance);
    friend ::Windows::Devices::Sensors::OrientationSensor^ UnwrapOrientationSensor(Handle<Value> value);
    friend bool IsOrientationSensorWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> OrientationSensor::s_constructorTemplate;

  v8::Handle<v8::Value> WrapOrientationSensor(::Windows::Devices::Sensors::OrientationSensor^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(OrientationSensor::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::OrientationSensor^ UnwrapOrientationSensor(Handle<Value> value)
  {
     return OrientationSensor::Unwrap<OrientationSensor>(value.As<Object>())->_instance;
  }

  void InitOrientationSensor(Handle<Object> exports)
  {
    OrientationSensor::Init(exports);
  }

  class OrientationSensorReading : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("OrientationSensorReading"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("quaternion"), QuaternionGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("rotationMatrix"), RotationMatrixGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("timestamp"), TimestampGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("yawAccuracy"), YawAccuracyGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("OrientationSensorReading"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    OrientationSensorReading(::Windows::Devices::Sensors::OrientationSensorReading^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::OrientationSensorReading^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensorReading^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::OrientationSensorReading^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      OrientationSensorReading *wrapperInstance = new OrientationSensorReading(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> QuaternionGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensorReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      OrientationSensorReading *wrapper = OrientationSensorReading::Unwrap<OrientationSensorReading>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::SensorQuaternion^ result = wrapper->_instance->Quaternion;
        return scope.Close(WrapSensorQuaternion(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RotationMatrixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensorReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      OrientationSensorReading *wrapper = OrientationSensorReading::Unwrap<OrientationSensorReading>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::SensorRotationMatrix^ result = wrapper->_instance->RotationMatrix;
        return scope.Close(WrapSensorRotationMatrix(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TimestampGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensorReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      OrientationSensorReading *wrapper = OrientationSensorReading::Unwrap<OrientationSensorReading>(info.This());

      try 
      {
        ::Windows::Foundation::DateTime result = wrapper->_instance->Timestamp;
        return scope.Close(NodeRT::Utils::DateTimeToJS(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> YawAccuracyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensorReading^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      OrientationSensorReading *wrapper = OrientationSensorReading::Unwrap<OrientationSensorReading>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::MagnetometerAccuracy result = wrapper->_instance->YawAccuracy;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::OrientationSensorReading^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapOrientationSensorReading(::Windows::Devices::Sensors::OrientationSensorReading^ wintRtInstance);
    friend ::Windows::Devices::Sensors::OrientationSensorReading^ UnwrapOrientationSensorReading(Handle<Value> value);
    friend bool IsOrientationSensorReadingWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> OrientationSensorReading::s_constructorTemplate;

  v8::Handle<v8::Value> WrapOrientationSensorReading(::Windows::Devices::Sensors::OrientationSensorReading^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(OrientationSensorReading::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::OrientationSensorReading^ UnwrapOrientationSensorReading(Handle<Value> value)
  {
     return OrientationSensorReading::Unwrap<OrientationSensorReading>(value.As<Object>())->_instance;
  }

  void InitOrientationSensorReading(Handle<Object> exports)
  {
    OrientationSensorReading::Init(exports);
  }

  class OrientationSensorReadingChangedEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("OrientationSensorReadingChangedEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("reading"), ReadingGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("OrientationSensorReadingChangedEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    OrientationSensorReadingChangedEventArgs(::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      OrientationSensorReadingChangedEventArgs *wrapperInstance = new OrientationSensorReadingChangedEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> ReadingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      OrientationSensorReadingChangedEventArgs *wrapper = OrientationSensorReadingChangedEventArgs::Unwrap<OrientationSensorReadingChangedEventArgs>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::OrientationSensorReading^ result = wrapper->_instance->Reading;
        return scope.Close(WrapOrientationSensorReading(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapOrientationSensorReadingChangedEventArgs(::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^ wintRtInstance);
    friend ::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^ UnwrapOrientationSensorReadingChangedEventArgs(Handle<Value> value);
    friend bool IsOrientationSensorReadingChangedEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> OrientationSensorReadingChangedEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapOrientationSensorReadingChangedEventArgs(::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(OrientationSensorReadingChangedEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::OrientationSensorReadingChangedEventArgs^ UnwrapOrientationSensorReadingChangedEventArgs(Handle<Value> value)
  {
     return OrientationSensorReadingChangedEventArgs::Unwrap<OrientationSensorReadingChangedEventArgs>(value.As<Object>())->_instance;
  }

  void InitOrientationSensorReadingChangedEventArgs(Handle<Object> exports)
  {
    OrientationSensorReadingChangedEventArgs::Init(exports);
  }

  class SimpleOrientationSensor : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SimpleOrientationSensor"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getCurrentOrientation"), FunctionTemplate::New(GetCurrentOrientation)->GetFunction());
      
                  
      Local<Function> addListenerFunc = FunctionTemplate::New(AddListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("addListener"), addListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("on"), addListenerFunc);
      Local<Function> removeListenerFunc = FunctionTemplate::New(RemoveListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeListener"), removeListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("off"), removeListenerFunc);
            
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("getDefault"), FunctionTemplate::New(GetDefault)->GetFunction());

      exports->Set(String::NewSymbol("SimpleOrientationSensor"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SimpleOrientationSensor(::Windows::Devices::Sensors::SimpleOrientationSensor^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::SimpleOrientationSensor^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SimpleOrientationSensor^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::SimpleOrientationSensor^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SimpleOrientationSensor *wrapperInstance = new SimpleOrientationSensor(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetCurrentOrientation(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SimpleOrientationSensor^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      SimpleOrientationSensor *wrapper = SimpleOrientationSensor::Unwrap<SimpleOrientationSensor>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::SimpleOrientation result;
          result = wrapper->_instance->GetCurrentOrientation();
          return scope.Close(Integer::New(static_cast<int>(result)));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> GetDefault(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sensors::SimpleOrientationSensor^ result;
          result = ::Windows::Devices::Sensors::SimpleOrientationSensor::GetDefault();
          return scope.Close(WrapSimpleOrientationSensor(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static v8::Handle<v8::Value> AddListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected arguments are eventName(string),callback(function)")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;
      
      Local<Function> callback = args[1].As<Function>();
      
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      if (NodeRT::Utils::CaseInsenstiveEquals(L"orientationChanged", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SimpleOrientationSensor^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        SimpleOrientationSensor *wrapper = SimpleOrientationSensor::Unwrap<SimpleOrientationSensor>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->OrientationChanged::add(
            ref new ::Windows::Foundation::TypedEventHandler<::Windows::Devices::Sensors::SimpleOrientationSensor^, ::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^>(
            [callbackObjPtr](::Windows::Devices::Sensors::SimpleOrientationSensor^ arg0, ::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapSimpleOrientationSensor(arg0);
                Handle<Value> wrappedArg1 = WrapSimpleOrientationSensorOrientationChangedEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else 
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
          tokenMap = Object::New();
          callback->SetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME), tokenMap);
      }

      tokenMap.As<Object>()->Set(args[1], CreateOpaqueWrapper(::Windows::Foundation::PropertyValue::CreateInt64(registrationToken.Value)));
                
      return scope.Close(Undefined());
    }

    static v8::Handle<v8::Value> RemoveListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected a string and a callback")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;

      if ((NodeRT::Utils::CaseInsenstiveEquals(L"orientationChanged", str)))
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Function> callback = args[1].As<Function>();
      Handle<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      Handle<Value> opaqueWrapperObj =  tokenMap.As<Object>()->Get(args[1]);

      if (opaqueWrapperObj.IsEmpty() || opaqueWrapperObj->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      OpaqueWrapper *opaqueWrapper = OpaqueWrapper::Unwrap<OpaqueWrapper>(opaqueWrapperObj.As<Object>());
            
      long long tokenValue = (long long) opaqueWrapper->GetObjectInstance();
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      registrationToken.Value = tokenValue;
        
      try 
      {
        if (NodeRT::Utils::CaseInsenstiveEquals(L"orientationChanged", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SimpleOrientationSensor^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          SimpleOrientationSensor *wrapper = SimpleOrientationSensor::Unwrap<SimpleOrientationSensor>(args.This());
          wrapper->_instance->OrientationChanged::remove(registrationToken);
        }
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }

      tokenMap.As<Object>()->Delete(args[0].As<String>());

      return scope.Close(Undefined());
    }
  private:
    ::Windows::Devices::Sensors::SimpleOrientationSensor^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSimpleOrientationSensor(::Windows::Devices::Sensors::SimpleOrientationSensor^ wintRtInstance);
    friend ::Windows::Devices::Sensors::SimpleOrientationSensor^ UnwrapSimpleOrientationSensor(Handle<Value> value);
    friend bool IsSimpleOrientationSensorWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SimpleOrientationSensor::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSimpleOrientationSensor(::Windows::Devices::Sensors::SimpleOrientationSensor^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SimpleOrientationSensor::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::SimpleOrientationSensor^ UnwrapSimpleOrientationSensor(Handle<Value> value)
  {
     return SimpleOrientationSensor::Unwrap<SimpleOrientationSensor>(value.As<Object>())->_instance;
  }

  void InitSimpleOrientationSensor(Handle<Object> exports)
  {
    SimpleOrientationSensor::Init(exports);
  }

  class SimpleOrientationSensorOrientationChangedEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SimpleOrientationSensorOrientationChangedEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("orientation"), OrientationGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("timestamp"), TimestampGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("SimpleOrientationSensorOrientationChangedEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SimpleOrientationSensorOrientationChangedEventArgs(::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SimpleOrientationSensorOrientationChangedEventArgs *wrapperInstance = new SimpleOrientationSensorOrientationChangedEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> OrientationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SimpleOrientationSensorOrientationChangedEventArgs *wrapper = SimpleOrientationSensorOrientationChangedEventArgs::Unwrap<SimpleOrientationSensorOrientationChangedEventArgs>(info.This());

      try 
      {
        ::Windows::Devices::Sensors::SimpleOrientation result = wrapper->_instance->Orientation;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TimestampGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SimpleOrientationSensorOrientationChangedEventArgs *wrapper = SimpleOrientationSensorOrientationChangedEventArgs::Unwrap<SimpleOrientationSensorOrientationChangedEventArgs>(info.This());

      try 
      {
        ::Windows::Foundation::DateTime result = wrapper->_instance->Timestamp;
        return scope.Close(NodeRT::Utils::DateTimeToJS(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSimpleOrientationSensorOrientationChangedEventArgs(::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^ wintRtInstance);
    friend ::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^ UnwrapSimpleOrientationSensorOrientationChangedEventArgs(Handle<Value> value);
    friend bool IsSimpleOrientationSensorOrientationChangedEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SimpleOrientationSensorOrientationChangedEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSimpleOrientationSensorOrientationChangedEventArgs(::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SimpleOrientationSensorOrientationChangedEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sensors::SimpleOrientationSensorOrientationChangedEventArgs^ UnwrapSimpleOrientationSensorOrientationChangedEventArgs(Handle<Value> value)
  {
     return SimpleOrientationSensorOrientationChangedEventArgs::Unwrap<SimpleOrientationSensorOrientationChangedEventArgs>(value.As<Object>())->_instance;
  }

  void InitSimpleOrientationSensorOrientationChangedEventArgs(Handle<Object> exports)
  {
    SimpleOrientationSensorOrientationChangedEventArgs::Init(exports);
  }

} } } } 

void init(Handle<Object> exports)
{
  if (FAILED(CoInitializeEx(nullptr, COINIT_MULTITHREADED)))
  {
    ThrowException(v8::Exception::Error(NodeRT::Utils::NewString(L"error in CoInitializeEx()")));
    return;
  }
  
  NodeRT::Windows::Devices::Sensors::InitMagnetometerAccuracyEnum(exports);
  NodeRT::Windows::Devices::Sensors::InitSimpleOrientationEnum(exports);
  NodeRT::Windows::Devices::Sensors::InitAccelerometer(exports);
  NodeRT::Windows::Devices::Sensors::InitAccelerometerReading(exports);
  NodeRT::Windows::Devices::Sensors::InitAccelerometerReadingChangedEventArgs(exports);
  NodeRT::Windows::Devices::Sensors::InitAccelerometerShakenEventArgs(exports);
  NodeRT::Windows::Devices::Sensors::InitInclinometer(exports);
  NodeRT::Windows::Devices::Sensors::InitInclinometerReading(exports);
  NodeRT::Windows::Devices::Sensors::InitInclinometerReadingChangedEventArgs(exports);
  NodeRT::Windows::Devices::Sensors::InitGyrometer(exports);
  NodeRT::Windows::Devices::Sensors::InitGyrometerReading(exports);
  NodeRT::Windows::Devices::Sensors::InitGyrometerReadingChangedEventArgs(exports);
  NodeRT::Windows::Devices::Sensors::InitCompass(exports);
  NodeRT::Windows::Devices::Sensors::InitCompassReading(exports);
  NodeRT::Windows::Devices::Sensors::InitCompassReadingChangedEventArgs(exports);
  NodeRT::Windows::Devices::Sensors::InitLightSensor(exports);
  NodeRT::Windows::Devices::Sensors::InitLightSensorReading(exports);
  NodeRT::Windows::Devices::Sensors::InitLightSensorReadingChangedEventArgs(exports);
  NodeRT::Windows::Devices::Sensors::InitSensorRotationMatrix(exports);
  NodeRT::Windows::Devices::Sensors::InitSensorQuaternion(exports);
  NodeRT::Windows::Devices::Sensors::InitOrientationSensor(exports);
  NodeRT::Windows::Devices::Sensors::InitOrientationSensorReading(exports);
  NodeRT::Windows::Devices::Sensors::InitOrientationSensorReadingChangedEventArgs(exports);
  NodeRT::Windows::Devices::Sensors::InitSimpleOrientationSensor(exports);
  NodeRT::Windows::Devices::Sensors::InitSimpleOrientationSensorOrientationChangedEventArgs(exports);

  NodeRT::Utils::RegisterNameSpace("Windows.Devices.Sensors", exports);
}


NODE_MODULE(binding, init)